@@ -517,6 +517,10 @@ var Application = GObject.registerClass({
 
         req.create_account_async((r, res) => {
             let account = req.create_account_finish(res);
+
+            Utils.clearAccountPassword(account);
+            Utils.clearIdentifyPassword(account);
+
             callback(account);
         });
     }
@@ -774,6 +778,9 @@ var Application = GObject.registerClass({
             n.connect('closed', () => {
                 account.remove_async((o, r) => {
                     a.remove_finish(r); // TODO: Check for errors
+
+                    Utils.clearAccountPassword(a);
+                    Utils.clearIdentifyPassword(a);
                 });
             });
             n.connect('undo', () => {
