@@ -140,8 +140,14 @@ var MainWindow = GObject.registerClass({
         if (GLib.get_application_name().toLowerCase().includes('snapshot'))
             this.get_style_context().add_class('snapshot');
 
+        this._viewHeight = this._calculateViewHeight();
         this._roomStack.connect('size-allocate', () => {
-            this.notify('view-height');
+            let oldViewHeight = this._viewHeight;
+            let newViewHeight = this._calculateViewHeight();
+            if (oldViewHeight !== newViewHeight) {
+                this._viewHeight = newViewHeight;
+                this.notify('view-height');
+            }
         });
 
         // command output notifications should not pop up over
@@ -219,9 +225,13 @@ var MainWindow = GObject.registerClass({
         return this._subtitle.length > 0;
     }
 
+    _calculateViewHeight() {
+        return this._roomStack.get_allocated_height() - this._roomStack.entry_area_height;
+    }
+
     // eslint-disable-next-line camelcase
     get view_height() {
-        return this._roomStack.get_allocated_height() - this._roomStack.entry_area_height;
+        return this._viewHeight;
     }
 
     _onAccountsReachableChanged() {
